# plain-pages changelog

## [0.10.4](https://github.com/dropseed/plain/releases/plain-pages@0.10.4) (2025-06-23)

### What's changed

- No user-facing changes. This release only updates internal project metadata and documentation.

### Upgrade instructions

- No changes required.
